<?php
/**
 * CSS related hooks.
 *
 * This file contains hook functions which are related to CSS.
 *
 * @package Easy_Commerce
 */

if ( ! function_exists( 'easy_commerce_trigger_custom_css_action' ) ) :

	/**
	 * Do action theme Custom CSS.
	 *
	 * @since 1.0.0
	 */
	function easy_commerce_trigger_custom_css_action() {

		/**
		 * Hook - easy_commerce_action_theme_custom_css.
		 */
		do_action( 'easy_commerce_action_theme_custom_css' );

	}

endif;

add_action( 'wp_head', 'easy_commerce_trigger_custom_css_action', 99 );

if ( ! function_exists( 'easy_commerce_add_theme_custom_font_css' ) ) :

	/**
	 * Inject theme custom font CSS.
	 *
	 * @since 1.0.0
	 */
	function easy_commerce_add_theme_custom_font_css() {

		$custom_css = '';

		$font_settings = easy_commerce_get_font_family_theme_settings_options();

		$required_fonts = array();

		if ( ! empty( $font_settings ) ) {
			foreach ( $font_settings as $key => $val ) {
				$option_value = easy_commerce_get_option( $key );
				if ( ! empty( $option_value ) && $val['default'] !== $option_value ) {
					$required_fonts[ $key ] = $option_value;
				}
			}
		}
		if ( empty( $required_fonts ) ) {

			// We do not need extra CSS.
			return;
		}

		foreach ( $required_fonts as $key => $font ) {

			$family = easy_commerce_get_font_family_from_key( $font );

			if ( ! empty( $family ) ) {

				switch ( $key ) {
					case 'font_site_default':
						$custom_css .= 'body{font-family:' . $family . '}' . "\n";
					break;

					case 'font_site_title':
						$custom_css .= '.site-title{font-family:' . $family . '}' . "\n";
					break;

					case 'font_site_tagline':
						$custom_css .= '.site-description{font-family:' . $family . '}' . "\n";
					break;

					case 'font_heading_tags':
						$custom_css .= 'h1,h2,h3,h4,h5,h6{font-family:' . $family . '}' . "\n";
					break;

					case 'font_content_title':
						$custom_css .= '.entry-header .entry-title{font-family:' . $family . '}' . "\n";
					break;

					case 'font_content_body':
						$custom_css .= '#content{font-family:' . $family . '}' . "\n";
					break;

					case 'font_navigation':
						$custom_css .= '#site-navigation ul li a{font-family:' . $family . '}' . "\n";
					break;

					default:
					break;
				}
			}
		}

		// Render style.
		if ( ! empty( $custom_css ) ) {
			echo '<style type="text/css">';
			echo $custom_css;
			echo '</style>';
		}

	}

endif;

add_action( 'easy_commerce_action_theme_custom_css', 'easy_commerce_add_theme_custom_font_css' );


if ( ! function_exists( 'easy_commerce_add_theme_custom_color_css' ) ) :

	/**
	 * Inject theme custom color CSS.
	 *
	 * @since 1.0.0
	 */
	function easy_commerce_add_theme_custom_color_css() {

		$custom_css = '';

		$color_settings = easy_commerce_get_color_theme_settings_options();

		$default = easy_commerce_get_default_colors();

		$required_colors = array();

		if ( ! empty( $color_settings ) ) {
		  foreach ($color_settings as $key => $val ) {
		    $option_value = easy_commerce_get_option( $key );
		    if ( ! empty( $option_value ) && $default[$key] != $option_value ) {
		      $required_colors[ $key ] = $option_value;
		    }
		  }
		}
		if ( empty( $required_colors ) ) {
		  // We do not need extra CSS.
		  return;
		}

		foreach ( $required_colors as $key => $color ) {

			switch ( $key ) {

				// Basic.
				case 'color_basic_text':
				  $custom_css .= 'body{color:' . $color . '}' . "\n";
				  break;
				case 'color_basic_link':
				  $custom_css .= 'a,a:visited{color:' . $color . '}' . "\n";
				  $custom_css .= '#mobile-trigger i,.meta-nav{background-color:' . $color . '}' . "\n";
				   $custom_css .= '.meta-nav,blockquote, q{border-color:' . $color . '}' . "\n";
				  break;
				case 'color_basic_link_hover':
				  $custom_css .= 'a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_basic_heading':
				  $custom_css .= 'h1,h2,h3,h4,h5,h6{color:' . $color . '}' . "\n";
				  break;
				case 'color_basic_button_text':
				$custom_css .= '#infinite-handle span,.search-box > a,a.button,.search-form .search-submit,.nav-links a,button, input[type="button"], input[type="reset"], input[type="submit"],#infinite-handle span button, #infinite-handle span button,.easy-commerce-woocommerce .slick-arrow i,.easy_commerce_widget_products_slider a.button,a.button:visited,.easy_commerce_widget_products_slider .cycle-prev, .easy_commerce_widget_products_slider .cycle-next,.easy-commerce-woocommerce ul.products li.product .button,a.custom-button,
					#sidebar-front-page-widget-area a.custom-button,
					#sidebar-front-page-widget-area  .easy-commerce-woocommerce .button{color:' . $color . '}' . "\n";

				$custom_css .= '.woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button{color:' . $color . '}' . "\n";
				 break;


				case 'color_basic_button_text_hover':
				  $custom_css .= 'a.custom-button:hover,.easy_commerce_widget_products_slider a.button:hover,.easy-commerce-woocommerce .slick-arrow i:hover,a.button,a.button:hover,.search-form .search-submit:hover,a.cta-button-primary:hover,.nav-links a:hover,a.button:hover, input[type="button"]:hover, input[type="reset"]:hover, input[type="submit"]:hover, #infinite-handle span button:hover,.easy-commerce-woocommerce ul.products li.product .button:hover,.easy_commerce_widget_products_slider .cycle-prev:hover, .easy_commerce_widget_products_slider .cycle-next:hover,.easy-commerce-woocommerce ul.products li.product .button:hover,#sidebar-front-page-widget-area a.custom-button:hover,#sidebar-front-page-widget-area  .easy-commerce-woocommerce .button:hover,
				  .slider-buttons a.custom-button.slider-button.button-secondary{color:' . $color . '}' . "\n";

				  $custom_css .= '.woocommerce #respond input#submit.alt:hover,.woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button.woocommerce:hover #respond input#submit.alt.disabled, .woocommerce #respond input#submit.alt.disabled:hover, .woocommerce #respond input#submit.alt:disabled, .woocommerce #respond input#submit.alt:disabled:hover, .woocommerce #respond input#submit.alt[disabled]:disabled, .woocommerce #respond input#submit.alt[disabled]:disabled:hover, .woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover, .woocommerce a.button.alt:disabled, .woocommerce a.button.alt:disabled:hover, .woocommerce a.button.alt[disabled]:disabled, .woocommerce a.button.alt[disabled]:disabled:hover, .woocommerce button.button.alt.disabled, .woocommerce button.button.alt.disabled:hover, .woocommerce button.button.alt:disabled, .woocommerce button.button.alt:disabled:hover, .woocommerce button.button.alt[disabled]:disabled, .woocommerce button.button.alt[disabled]:disabled:hover, .woocommerce input.button.alt.disabled, .woocommerce input.button.alt.disabled:hover, .woocommerce input.button.alt:disabled, .woocommerce input.button.alt:disabled:hover, .woocommerce input.button.alt[disabled]:disabled, .woocommerce input.button.alt[disabled]:disabled:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover:hover,a.custom-button.btn-call-to-action.btn-call-to-secondary{color:' . $color . '}' . "\n";
				  break;

				case 'color_basic_button_background':
				  $custom_css .= 'a.custom-button,.easy_commerce_widget_products_slider a.button,.easy-commerce-woocommerce .slick-arrow i,#infinite-handle span,.search-box > a,a.button,button,a.links-btn::after,.search-form .search-submit,.woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .woocommerce #respond input#submit, .woocommerce a.button, .woocommerce button.button, .woocommerce input.button,.easy-commerce-woocommerce ul.products li.product .button,.easy_commerce_widget_products_slider .cycle-prev, .easy_commerce_widget_products_slider .cycle-next,.woocommerce ul.products li.product .button{background-color:' . $color . '}' . "\n";
				  $custom_css .= 'a.cta-button-primary,button, input[type="button"], input[type="reset"], input[type="submit"],#infinite-handle span button,.easy-commerce-woocommerce ul.products li.product .button,#sidebar-front-page-widget-area a.custom-button,#sidebar-front-page-widget-area  .easy-commerce-woocommerce .button,.slider-buttons a.custom-button.slider-button.button-secondary:hover{background-color:' . $color . '}' . "\n";
				  break;

				case 'color_basic_button_background_hover':
				  $custom_css .= 'a.custom-button:hover,.easy_commerce_widget_products_slider a.button:hover,.easy-commerce-woocommerce .slick-arrow i:hover,#infinite-handle span:hover,.search-box > a:hover,a.button:hover,a.links-btn:hover::after,.search-form .search-submit:hover,a.cta-button-primary:hover,.nav-links a:hover,button:hover,a.button:hover, input[type="button"]:hover, input[type="reset"]:hover, input[type="submit"]:hover,#infinite-handle span button,.easy-commerce-woocommerce ul.products li.product .button:hover,.easy_commerce_widget_products_slider .cycle-prev:hover, .easy_commerce_widget_products_slider .cycle-next:hover,.woocommerce ul.products li.product .button:hover,.easy-commerce-woocommerce ul.products li.product .button:hover,#sidebar-front-page-widget-area a.custom-button:hover,#sidebar-front-page-widget-area  .easy-commerce-woocommerce .button:hover,.slider-buttons a.custom-button.slider-button.button-secondary{background-color:' . $color . '}' . "\n";
				  $custom_css .= '.woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover, .woocommerce input.button.alt:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button.woocommerce:hover #respond input#submit.alt.disabled, .woocommerce #respond input#submit.alt.disabled:hover, .woocommerce #respond input#submit.alt:disabled, .woocommerce #respond input#submit.alt:disabled:hover, .woocommerce #respond input#submit.alt[disabled]:disabled, .woocommerce #respond input#submit.alt[disabled]:disabled:hover, .woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover, .woocommerce a.button.alt:disabled, .woocommerce a.button.alt:disabled:hover, .woocommerce a.button.alt[disabled]:disabled, .woocommerce a.button.alt[disabled]:disabled:hover, .woocommerce button.button.alt.disabled, .woocommerce button.button.alt.disabled:hover, .woocommerce button.button.alt:disabled, .woocommerce button.button.alt:disabled:hover, .woocommerce button.button.alt[disabled]:disabled, .woocommerce button.button.alt[disabled]:disabled:hover, .woocommerce input.button.alt.disabled, .woocommerce input.button.alt.disabled:hover, .woocommerce input.button.alt:disabled, .woocommerce input.button.alt:disabled:hover, .woocommerce input.button.alt[disabled]:disabled, .woocommerce input.button.alt[disabled]:disabled:hover, .woocommerce #respond input#submit:hover, .woocommerce a.button:hover, .woocommerce button.button:hover, .woocommerce input.button:hover{background-color:' . $color . '}' . "\n";
				  break;

				//Top Header.

				case 'color_top_header_background':
				  $custom_css .= '#tophead {background-color:' . $color . '}' . "\n";
				  break;
				case 'color_top_header_icon':
				  $custom_css .= '.header-social-wrapper .easy_commerce_widget_social li a::before,#quick-contact li::before,#login-section .account-login a:before{color:' . $color . '}' . "\n";
				  break;
				case 'color_top_header_text':
				  $custom_css .= '#tophead,#quick-contact li{color:' . $color . '}' . "\n";
				break;
				case 'color_top_header_link':
				  $custom_css .= '#tophead a{color:' . $color . '}' . "\n";
				break;
				  case 'color_top_header_link_hover':
				$custom_css .= '#tophead a:hover{color:' . $color . '}' . "\n";
				break;


				// Header.
				case 'color_header_background':
				  $custom_css .= '#masthead,.header-search-wrapper .search-form input.search-field, .header-search-wrapper .woocommerce-product-search input.search-field,#main-nav {background-color:' . $color . '}' . "\n";
				  break;
				case 'color_header_title':
				  $custom_css .= '#site-identity .site-title > a{color:' . $color . '}' . "\n";
		        break;
				case 'color_header_title_hover':
				  $custom_css .= '#site-identity .site-title > a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_header_tagline':
				  $custom_css .= '.site-description{color:' . $color . '}' . "\n";
				  break;
				case 'color_header_icon':
				  $custom_css .= '#cart-section a{color:' . $color . '}' . "\n";
		        break;
				case 'color_header_icon_value':
				$custom_css .= '#cart-section strong{color:' . $color . '}' . "\n";
				  break;
				case 'color_header_icon_value_background':
				$custom_css .= '#cart-section strong{background-color:' . $color . '}' . "\n";
				  break;

			   // Primary Menu.
				case 'color_primary_menu_background':
				  $custom_css .= '#site-navigation{background-color:' . $color . '}' . "\n";
				break;

				case 'color_primary_menu_link':
				  $custom_css .= '#main-nav ul li a,.dropdown-toggle::after{color:' . $color . '}' . "\n";
				  break;
				case 'color_primary_menu_link_hover':
				  $custom_css .= '#main-nav ul li a:hover,#main-nav li.current-menu-item > a,
				  #main-nav li.current_page_item > a,#main-nav ul li:hover > a{color:' . $color . '}' . "\n";
				  $custom_css .= '.main-navigation li:hover:before, .main-navigation li.current-menu-item:before, .main-navigation li.current_page_item:before,.main-navigation li:hover:after, .main-navigation li.current-menu-item:after, .main-navigation li.current_page_item:after{background-color:' . $color . '}' . "\n";
				break;
				case 'color_primary_submenu_background':
				    $custom_css .= '.main-navigation li ul{background-color:' . $color . '}' . "\n";
				break;

			// Featured section.
				case 'color_featured_section_background':
				  $custom_css .= '#featured-section{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_featured_section_title':
				  $custom_css .= '#featured-section a,#featured-section h3,#featured-slider .slider-caption h3,#featured-slider .slider-caption h3 a{color:' . $color . '}' . "\n";
		        break;
				case 'color_featured_section_title_hover':
				  $custom_css .= '#featured-section a:hover,#featured-slider .slider-caption h3 a:hover{color:' . $color . '}' . "\n";
				break;
				case 'color_featured_section_text':
				  $custom_css .= '#featured-slider .slider-caption p,#featured-section p{color:' . $color . '}' . "\n";
			  	break;
			  	case 'color_featured_section_button':
				  $custom_css .= '#featured-section .slider-buttons a.custom-button,#featured-section a.custom-button.slider-button.button-secondary:hover{color:' . $color . '}' . "\n";
			  	break;
			  	case 'color_featured_section_button_hover':
				  $custom_css .= '#featured-section .slider-buttons a.custom-button:hover,#featured-section a.custom-button.slider-button.button-secondary{color:' . $color . '}' . "\n";
			  	break;
			  	case 'color_featured_section_button_background':
				  $custom_css .= '#featured-section .slider-buttons a.custom-button,#featured-section a.custom-button.slider-button.button-secondary:hover{background-color:' . $color . '}' . "\n";
			  	break;
			  	case 'color_featured_section_button_background_hover':
				  $custom_css .= '#featured-section .slider-buttons a.custom-button:hover,#featured-section a.custom-button.slider-button.button-secondary{background-color:' . $color . '}' . "\n";
			  	break;
			  	case 'color_slider_icon':
				  $custom_css .= '#featured-section .cycle-prev, #featured-section .cycle-next{color:' . $color . '}' . "\n";
				  break;
				case 'color_slider_icon_hover':
				  $custom_css .= '#featured-section .cycle-prev:hover, #featured-section .cycle-next:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_slider_icon_background':
				  $custom_css .= '#featured-section .cycle-prev, #featured-section .cycle-next{background-color:' . $color . '}' . "\n";

				  break;
				case 'color_slider_icon_background_hover':
				  $custom_css .= '#featured-section .cycle-prev:hover, #featured-section .cycle-next:hover{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_slider_pager':
				  $custom_css .= '#featured-section .pager-box{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_slider_pager_active':
				  $custom_css .= '#featured-section .pager-box:hover,#featured-section .pager-box.cycle-pager-active{background-color:' . $color . '}' . "\n";
				  break;
				// Content.
				case 'color_content_background':
				  $custom_css .= '#content{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_content_primary_background':
				  $custom_css .= '#main,.entry-content-wrapper{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_content_title':
				  $custom_css .= '#primary .entry-title{color:' . $color . '}' . "\n";
				  $custom_css .= '#primary h1.entry-title::after{background-color:' . $color . '}' . "\n";

				  
				  break;
				case 'color_content_text':
				  $custom_css .= '#primary {color:' . $color . '}' . "\n";
				  break;
				case 'color_content_link':
				  $custom_css .= '#primary article a{color:' . $color . '}' . "\n";
				  break;
				case 'color_content_link_hover':
				  $custom_css .= '#primary article a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_content_meta_link':
				  $custom_css .= '#primary .entry-meta > span a,#primary .entry-footer > span a{color:' . $color . '}' . "\n";
				  break;
				case 'color_content_meta_link_hover':
				  $custom_css .= '#primary .entry-meta > span a:hover,#primary  .entry-footer > span a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_content_meta_icon':
				  $custom_css .= '#primary .entry-meta > span::before,#primary  .entry-footer > span::before{color:' . $color . '}' . "\n";
				  break;

				// Sidebar.
				case 'color_sidebar_background':
				  $custom_css .= '.sidebar{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_sidebar_title':
				  $custom_css .= '.sidebar .widget-title{color:' . $color . '}' . "\n";
				  $custom_css .= '.sidebar .widget-title::after{background-color:' . $color . '}' . "\n";  
				  break;
				case 'color_sidebar_text':
				  $custom_css .= '.sidebar{color:' . $color . '}' . "\n";
				  break;
				case 'color_sidebar_link':
				  $custom_css .= '.sidebar .widget a,.sidebar .widget li{color:' . $color . '}' . "\n";
				  break;
				case 'color_sidebar_link_hover':
				  $custom_css .= '.sidebar .widget a:hover,.sidebar .widget li:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_sidebar_list_icon':
				  $custom_css .= '.sidebar ul li::before{color:' . $color . '}' . "\n";
				  break;

				// Footer area.
				case 'color_footer_area_background':
				  $custom_css .= '#colophon{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_footer_area_text':
				  $custom_css .= '#colophon{color:' . $color . '}' . "\n";
				  break;
				case 'color_footer_area_link':
				  $custom_css .= '#colophon a{color:' . $color . '}' . "\n";
				  break;
				case 'color_footer_area_link_hover':
				  $custom_css .= '#colophon a:hover{color:' . $color . '}' . "\n";
				  break;

				// Go To Top.
			    case 'color_goto_top_icon':
				  $custom_css .= '#btn-scrollup i.fa{color:' . $color . '}' . "\n";
				  break;
				case 'color_goto_top_icon_hover':
				  $custom_css .= '#btn-scrollup i.fa:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_goto_top_background':
				  $custom_css .= '#btn-scrollup{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_goto_top_background_hover':
				  $custom_css .= '#btn-scrollup:hover{background-color:' . $color . '}' . "\n";
				  break;


				// Pagination.
				case 'color_pagination_link':
				  $custom_css .= '.pagination .nav-links .page-numbers,.woocommerce nav.woocommerce-pagination ul li a,.navigation .nav-links a, .navigation .nav-links a {color:' . $color . '}' . "\n";
				  break;
				case 'color_pagination_link_hover':
				  $custom_css .= '.navigation .nav-links a:hover, .navigation .nav-links a:hover,.pagination .nav-links .page-numbers:hover,.woocommerce nav.woocommerce-pagination ul li a:hover,.woocommerce nav.woocommerce-pagination ul li a:focus, .woocommerce nav.woocommerce-pagination ul li a:hover, .woocommerce nav.woocommerce-pagination ul li span.current{color:' . $color . '}' . "\n";
				  break;
				case 'color_pagination_link_background':
				  $custom_css .= '.pagination .nav-links .page-numbers,.woocommerce nav.woocommerce-pagination ul li a,.navigation .nav-links a, .navigation .nav-links a{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_pagination_link_background_hover':
				  $custom_css .= '.navigation .nav-links a:hover, .navigation .nav-links a:hover,.woocommerce nav.woocommerce-pagination ul li a:focus, .woocommerce nav.woocommerce-pagination ul li a:hover, .woocommerce nav.woocommerce-pagination ul li span.current,.pagination .nav-links .page-numbers:hover,.woocommerce nav.woocommerce-pagination ul li a:hover{background-color:' . $color . '}' . "\n";
				  break;

				// Breadcrumb.
				case 'color_breadcrumb_background':
				  $custom_css .= '#breadcrumb{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_breadcrumb_link':
				  $custom_css .= '#crumbs a,#breadcrumb a{color:' . $color . '}' . "\n";
				  break;
				case 'color_breadcrumb_link_hover':
				  $custom_css .= '#crumbs a:hover,#breadcrumb a:hover{color:' . $color . '}' . "\n";
				  break;
				case 'color_breadcrumb_text':
				  $custom_css .= '#breadcrumb,#breadcrumb .breadcrumb-trail li::after, #crumbs li::after{color:' . $color . '}' . "\n";
				  break;

				// Footer Widgets.
				case 'color_footer_widgets_background':
				  $custom_css .= '#footer-widgets{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_footer_widgets_title':
				  $custom_css .= '#footer-widgets .widget-title{color:' . $color . '}' . "\n";
				  $custom_css .= '#footer-widgets .separator{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_footer_widgets_text':
				  $custom_css .= '#footer-widgets {color:' . $color . '}' . "\n";
				  break;
				case 'color_footer_widgets_link':
				  $custom_css .= '#footer-widgets a{color:' . $color . '}' . "\n";
				  $custom_css .= '#footer-widgets h3.widget-title::after{background-color:' . $color . '}' . "\n";
			      $custom_css .= '#footer-widgets  break;{border-color:' . $color . '}' . "\n";
				break;

				case 'color_footer_widgets_link_hover':
				  $custom_css .= '#footer-widgets a:hover{color:' . $color . '}' . "\n";
				  break;

				// Home Page Widgets.
				case 'color_home_widgets_background':
				  $custom_css .= '#sidebar-front-page-widget-area,#sidebar-front-page-widget-area .widget{background-color:' . $color . '}' . "\n";
				  break;
				case 'color_home_widgets_title':
				  $custom_css .= '#sidebar-front-page-widget-area .widget-title{color:' . $color . '}' . "\n";

				  break;
				 case 'color_home_widgets_subtitle':
				  $custom_css .= '#sidebar-front-page-widget-area .widget-subtitle{color:' . $color . '}' . "\n";
				  break;
				case 'color_home_widgets_text':
				  $custom_css .= '#sidebar-front-page-widget-area,#sidebar-front-page-widget-area p{color:' . $color . '}' . "\n";
				  break;
				case 'color_home_widgets_link':
				  $custom_css .= '#sidebar-front-page-widget-area a{color:' . $color . '}' . "\n";
				  $custom_css .= '#sidebar-front-page-widget-area .widget-title span{color:' . $color . '}' . "\n";

				  
				  break;
				case 'color_home_widgets_link_hover':
				  $custom_css .= '#sidebar-front-page-widget-area a:hover{color:' . $color . '}' . "\n";
				  break;

			  default:
			    break;

			}

		}

		// Render style.
		if ( ! empty( $custom_css ) ) {
		  echo '<style type="text/css">';
		  echo $custom_css;
		  echo '</style>';
		}

	}

endif;

add_action( 'easy_commerce_action_theme_custom_css', 'easy_commerce_add_theme_custom_color_css', 25 );
